@@ -173,11 +173,11 @@ class PropertiesModel(updates.UpdateInterface):
 
             # Determine the frame needed for this clip (based on the position on the timeline)
             time_diff = (requested_time - clip.Position()) + clip.Start()
-            self.frame_number = int(time_diff * fps_float) + 1
+            self.frame_number = round(time_diff * fps_float) + 1
 
             # Calculate biggest and smallest possible frames
-            min_frame_number = int((clip.Start() * fps_float)) + 1
-            max_frame_number = int((clip.End() * fps_float)) + 1
+            min_frame_number = round((clip.Start() * fps_float)) + 1
+            max_frame_number = round((clip.End() * fps_float)) + 1
 
             # Adjust frame number if out of range
             if self.frame_number < min_frame_number:
@@ -485,7 +485,9 @@ class PropertiesModel(updates.UpdateInterface):
                         log.info("Created new point at X=%s" % self.frame_number)
                         c.data[property_key]["Points"].append({'co': {'X': self.frame_number, 'Y': new_value}, 'interpolation': 1})
 
-                elif property_type == "int":
+            if not clip_updated:
+                # If no keyframe was found, set a basic property
+                if property_type == "int":
                     # Integer
                     clip_updated = True
                     c.data[property_key] = int(new_value)
@@ -634,8 +636,6 @@ class PropertiesModel(updates.UpdateInterface):
                         my_icon = QPixmap(os.path.join(info.IMAGES_PATH, "keyframe-%s.png" % interpolation))
                         col.setData(my_icon, Qt.DecorationRole)
 
-                        log.info(os.path.join(info.IMAGES_PATH, "keyframe-%s.png" % interpolation))
-
                         # Set the background color of the cell
                         if keyframe:
                             col.setBackground(QColor("green"))  # Highlight keyframe background
